@@ -79,14 +79,14 @@ L<Mojolicious::Command> and implements the following new ones.
   my $description = $app->description;
   $app            = $app->description('Foo');
 
-Short description of this command, used for the command list.
+Short description of this command. Used for the command list.
 
 =head2 usage
 
   my $usage = $app->usage;
   $app      = $app->usage('Foo');
 
-Usage information for this command, used for the help screen.
+Usage information for this command. Used for the help screen.
 
 =head1 METHODS
 
@@ -113,7 +113,7 @@ __DATA__
 use strict;
 use warnings;
 
-use Mojo::File 'curfile';
+use Mojo::File qw(curfile);
 use lib curfile->dirname->sibling('lib')->to_string;
 use Mojolicious::Commands;
 
